'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var g = require('@antv/g');
var DomInteraction = require('@antv/g-plugin-dom-interaction');
var SVGRenderer = require('@antv/g-plugin-svg-renderer');
var SVGPicker = require('@antv/g-plugin-svg-picker');
var manaSyringe = require('mana-syringe');
var tslib = require('tslib');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

var DomInteraction__namespace = /*#__PURE__*/_interopNamespace(DomInteraction);
var SVGRenderer__namespace = /*#__PURE__*/_interopNamespace(SVGRenderer);
var SVGPicker__namespace = /*#__PURE__*/_interopNamespace(SVGPicker);

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;

  _setPrototypeOf(subClass, superClass);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

var SVGContextService = /*#__PURE__*/function () {
  function SVGContextService() {
    this.$container = void 0;
    this.$namespace = void 0;
    this.dpr = void 0;
    this.canvasConfig = void 0;
  }

  var _proto = SVGContextService.prototype;

  _proto.init = function init() {
    var container = this.canvasConfig.container; // create container

    this.$container = g.isString(container) ? document.getElementById(container) : container;

    if (this.$container) {
      if (!this.$container.style.position) {
        this.$container.style.position = 'relative';
      }

      var $namespace = SVGRenderer.createSVGElement('svg');
      $namespace.setAttribute('width', "" + this.canvasConfig.width);
      $namespace.setAttribute('height', "" + this.canvasConfig.height);
      this.$container.appendChild($namespace);
      this.$namespace = $namespace;
    }

    var dpr = window.devicePixelRatio || 1;
    dpr = dpr >= 1 ? Math.ceil(dpr) : 1;
    this.dpr = dpr;
  } // @ts-ignore
  ;

  _proto.getDomElement = function getDomElement() {
    return this.$namespace;
  };

  _proto.getContext = function getContext() {
    return this.$namespace;
  };

  _proto.getDPR = function getDPR() {
    return this.dpr;
  };

  _proto.getBoundingClientRect = function getBoundingClientRect() {
    var _this$$namespace;

    return (_this$$namespace = this.$namespace) === null || _this$$namespace === void 0 ? void 0 : _this$$namespace.getBoundingClientRect();
  };

  _proto.destroy = function destroy() {
    // destroy context
    if (this.$container && this.$namespace && this.$namespace.parentNode) {
      this.$container.removeChild(this.$namespace);
    }
  };

  _proto.resize = function resize(width, height) {
    if (this.$namespace) {
      this.$namespace.setAttribute('width', "" + width);
      this.$namespace.setAttribute('height', "" + height);
    }
  };

  _proto.applyCursorStyle = function applyCursorStyle(cursor) {
    if (this.$container) {
      this.$container.style.cursor = cursor;
    }
  };

  return SVGContextService;
}();

tslib.__decorate([manaSyringe.inject(g.CanvasConfig), tslib.__metadata("design:type", Object)], SVGContextService.prototype, "canvasConfig", void 0);

SVGContextService = tslib.__decorate([manaSyringe.singleton({
  token: g.ContextService
})], SVGContextService);

var containerModule = manaSyringe.Module(function (register) {
  /**
   * implements ContextService
   */
  register(SVGContextService);
});
var ContextRegisterPlugin = /*#__PURE__*/function () {
  function ContextRegisterPlugin() {
    this.name = 'svg-context-register';
  }

  var _proto = ContextRegisterPlugin.prototype;

  _proto.init = function init(container) {
    container.load(containerModule, true);
  };

  _proto.destroy = function destroy(container) {
    container.unload(containerModule);
  };

  return ContextRegisterPlugin;
}();

var Renderer = /*#__PURE__*/function (_AbstractRenderer) {
  _inheritsLoose(Renderer, _AbstractRenderer);

  function Renderer(config) {
    var _this;

    _this = _AbstractRenderer.call(this, config) || this;

    _this.registerPlugin(new ContextRegisterPlugin());

    _this.registerPlugin(new SVGRenderer.Plugin());

    _this.registerPlugin(new DomInteraction.Plugin());

    _this.registerPlugin(new SVGPicker.Plugin());

    return _this;
  }

  return Renderer;
}(g.AbstractRenderer);

exports.DomInteraction = DomInteraction__namespace;
exports.SVGRenderer = SVGRenderer__namespace;
exports.SVGPicker = SVGPicker__namespace;
exports.Renderer = Renderer;
